import Vue from 'vue'
import Vuex from 'vuex'
import axios from 'axios'

Vue.use(Vuex)

const products = {
  namespaced: true,
  state: () => ({
    isLoading: false,
    data: [],
    hasError: false,
  }),
  mutations: {
    setData(state, payload) {
      state.data = payload;
    },
    setIsLoading(state, payload) {
      state.isLoading = payload;
    },
    setHasError(state, payload) {
      state.hasError = payload;
    }
  },
  actions: {
    fetchProducts({ commit }, params) {
      commit('setIsLoading', true);
      return axios.get('http://localhost:3000/products', params)
        .then(({ data }) => {
          commit('setData', data);
        })
        .catch(() => {
          commit('setHasError', true);
        })
        .finally(() => {
          commit('setIsLoading', false);
        })
    },
  },
  getters: {}
}

const store = new Vuex.Store({
  modules: {
    products,
  }
})

export default store;